@@ -6,7 +6,7 @@
 
 #include "connection.h"
 
-#include <KIO/TransferJob>
+#include <QNetworkAccessManager>
 #include <QUrlQuery>
 
 #include "bugzilla_debug.h"
@@ -19,12 +19,7 @@ namespace Bugzilla
 class GlobalConnection
 {
 public:
-    ~GlobalConnection()
-    {
-        delete m_connection;
-    }
-
-    Connection *m_connection = new HTTPConnection;
+    std::unique_ptr<Connection> m_connection = std::make_unique<HTTPConnection>();
 };
 
 Q_GLOBAL_STATIC(GlobalConnection, s_connection)
@@ -36,8 +31,7 @@ Connection &connection()
 
 void setConnection(Connection *newConnection)
 {
-    delete s_connection->m_connection;
-    s_connection->m_connection = newConnection;
+    s_connection->m_connection.reset(newConnection);
 }
 
 HTTPConnection::HTTPConnection(const QUrl &root, QObject *parent)
@@ -56,22 +50,27 @@ void HTTPConnection::setToken(const QString &authToken)
 APIJob *HTTPConnection::get(const QString &path, const Query &query) const
 {
     qCDebug(BUGZILLA_LOG) << path << query.toString();
-    auto job = new TransferAPIJob(KIO::get(url(path, query), KIO::Reload, KIO::HideProgressInfo));
+    auto job = new NetworkAPIJob(url(path, query), [](QNetworkAccessManager &manager, QNetworkRequest &request) -> QNetworkReply * {
+        return manager.get(request);
+    });
     return job;
 }
 
 APIJob *HTTPConnection::post(const QString &path, const QByteArray &data, const Query &query) const
 {
     qCDebug(BUGZILLA_LOG) << path << query.toString();
-    auto job = new TransferAPIJob(KIO::http_post(url(path, query), data, KIO::HideProgressInfo));
+    auto job = new NetworkAPIJob(url(path, query), [data](QNetworkAccessManager &manager, QNetworkRequest &request) -> QNetworkReply * {
+        return manager.post(request, data);
+    });
     return job;
 }
 
 APIJob *HTTPConnection::put(const QString &path, const QByteArray &data, const Query &query) const
 {
     qCDebug(BUGZILLA_LOG) << path << query.toString();
-    auto job = new TransferAPIJob(KIO::put(url(path, query), KIO::HideProgressInfo));
-    job->setPutData(data);
+    auto job = new NetworkAPIJob(url(path, query), [data](QNetworkAccessManager &manager, QNetworkRequest &request) -> QNetworkReply * {
+        return manager.put(request, data);
+    });
     return job;
 }
 
@@ -103,3 +102,5 @@ QUrl HTTPConnection::url(const QString &appendix, Query query) const
 }
 
 } // namespace Bugzilla
+
+#include "moc_connection.cpp"
