@@ -21,6 +21,14 @@ using namespace std::chrono_literals;
 
 bool NotifyTruck::handle(const Coredump &dump)
 {
+    if (!dump.m_rawData.value(dump.keyPickup()).isEmpty()) {
+        // Pickups are currently not supported for notify handling. The problem is that we don't know if we already
+        // notified on a crash or not because we have no persistent storage. To fix this we'd probably need to
+        // rejigger things substantially and insert a pickup key into the journal that the processor can then look for.
+        // Except then the processor needs to hold on to dumps until the entire journal is processed. All a bit awkward.
+        return false;
+    }
+
     auto notification = new KNotification(QStringLiteral("applicationcrash"));
 
     // immediate exit signal. This gets disconnected should `activated` arrive first (in that case we
@@ -36,13 +44,14 @@ bool NotifyTruck::handle(const Coredump &dump)
     } else {
         notification->setTitle(QStringLiteral("He's dead, Jim"));
         notification->setText(QStringLiteral("%1 [%2]").arg(dump.exe, QString::number(dump.pid)));
-        notification->setActions({QStringLiteral("gdb")});
+        auto gdbAction = notification->addAction(QStringLiteral("gdb"));
 
         const auto pid = dump.pid;
 
-        QObject::connect(notification, &KNotification::activated, notification, [pid, this, notification]() {
+        connect(gdbAction, &KNotificationAction::activated, notification, [pid, this, notification]() {
             notification->disconnect(this);
             auto job = new KTerminalLauncherJob(QStringLiteral("coredumpctl gdb %1").arg(QString::number(pid)), this);
+            job->setProcessEnvironment(QProcessEnvironment::systemEnvironment());
             connect(job, &KJob::result, this, [job] {
                 if (job->error() != KJob::NoError) {
                     qWarning() << job->errorText();
@@ -70,3 +79,5 @@ bool NotifyTruck::handle(const Coredump &dump)
     qApp->exec();
     return true;
 }
+
+#include "moc_NotifierTruck.cpp"
